==> wlassistant-trinity-14.1.1.tar.xz: wlassistant-trinity-14.1.1/src/ui_netparamswizard.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Pawel Nawrocki                                  *
 *   pnawrocki@interia.pl                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef UI_NETPARAMSWIZARD_IMPL_H
#define UI_NETPARAMSWIZARD_IMPL_H

#include <tqlistview.h>

#include "ui_NetParamsWizard.h"


class WANetParams;
class ui_NetParamsWizard : public NetParamsWizard
{
        TQ_OBJECT
  

public:
        ui_NetParamsWizard(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
        ~ui_NetParamsWizard();
        /*$PUBLIC_FUNCTIONS$*/
	void setWepEnabled( bool w );
	void setWpaEnabled( bool w, TQStringList settings = TQStringList() );
	void setEssidEnabled( bool e );
        WANetParams readNetParams( WANetParams & np );

public slots:
        /*$PUBLIC_SLOTS$*/

protected:
        /*$PROTECTED_FUNCTIONS$*/

protected slots:
        /*$PROTECTED_SLOTS$*/
        virtual void          next();
};

#endif

==> wlassistant-trinity_14.1.5.orig.tar.xz: wlassistant-trinity-14.1.5/src/ui_netparamswizard.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Pawel Nawrocki                                  *
 *   pnawrocki@interia.pl                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef UI_NETPARAMSWIZARD_IMPL_H
#define UI_NETPARAMSWIZARD_IMPL_H

#include <tqlistview.h>

#include "ui_NetParamsWizard.h"


class WANetParams;
class ui_NetParamsWizard : public NetParamsWizard
{
        TQ_OBJECT
  

public:
        ui_NetParamsWizard(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
        ~ui_NetParamsWizard();
        /*$PUBLIC_FUNCTIONS$*/
	void setWepEnabled( bool w );
	void setWpaEnabled( bool w, TQStringList settings = TQStringList() );
	void setEssidEnabled( bool e );
        WANetParams readNetParams( WANetParams & np );

public slots:
        /*$PUBLIC_SLOTS$*/

protected:
        /*$PROTECTED_FUNCTIONS$*/

protected slots:
        /*$PROTECTED_SLOTS$*/
        virtual void          next();
};

#endif
